@@ -1,20 +1,20 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2012
- * Mail: info@open-xchange.com
+ * © 2016 OX Software GmbH.
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
-define('io.ox/office/tk/popup/tooltip',
-    ['io.ox/office/tk/utils',
-     'io.ox/office/tk/popup/basepopup'
-    ], function (Utils, BasePopup) {
+define('io.ox/office/tk/popup/tooltip', [
+    'io.ox/office/tk/utils',
+    'io.ox/office/tk/popup/basepopup'
+], function (Utils, BasePopup) {
 
     'use strict';
 
@@ -38,10 +38,10 @@ define('io.ox/office/tk/popup/tooltip',
         // base constructor ---------------------------------------------------
 
         BasePopup.call(this, Utils.extendOptions({
-            anchorPadding: 3,
             restrictSize: 'width',
             minSize: 150,
-            maxSize: 450
+            maxSize: 450,
+            anchorPadding: 3
         }, initOptions));
 
         // methods ------------------------------------------------------------
